@@ -1,5 +1,5 @@
 package Playwright::Util;
-$Playwright::Util::VERSION = '0.003';
+$Playwright::Util::VERSION = '0.004';
 use strict;
 use warnings;
 
@@ -29,6 +29,12 @@ sub request ( $method, $url, $port, $ua, %args ) {
     return $msg;
 }
 
+sub arr2hash ( $array, $primary_key ) {
+    my $inside_out = {};
+    @$inside_out{ map { $_->{$primary_key} } @$array } = @$array;
+    return $inside_out;
+}
+
 1;
 
 __END__
@@ -43,7 +49,7 @@ Playwright::Util - Common utility functions for the Playwright module
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head2 request(STRING method, STRING url, INTEGER port, LWP::UserAgent ua, HASH args) = HASH
 
